import { concat, pluck, uniq } from "ramda";
import { create } from "zustand";

interface Product {
  id: string;
  name: string;
}

interface ProductsStore {
  products: Product[];
  selctedProducts: string[];
  append: (code: string) => void;
  remove: (code: string) => void;
  unselectAll: () => void;
  selectAll: () => void;
}

export const useProductsStore = create<ProductsStore>((set, get) => ({
  products: [],
  selctedProducts: [],
  append: (code: string) => set((state) => ({ selctedProducts: [...state.selctedProducts, code] })),
  remove: (code: string) =>
    set((state) => ({ selctedProducts: state.selctedProducts.filter((item) => item !== code) })),
  unselectAll: () => set({ selctedProducts: [] }),
  selectAll: () => {
    const products = pluck("id", get().products);
    const selectedProducts = uniq(concat(get().selctedProducts, products));
    set({ selctedProducts: selectedProducts });
  },
}));
